# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Santé)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------  


#!/bin/bash

 echo  "in ThirdParty-install-ITK.sh, source " $PWD/scripts/CreaTools-configure.sh
 if [ ! -f $PWD/scripts/CreaTools-configure.sh ]
 then 
   echo
   echo "..ERROR.."
   echo "==================================================="
   echo "REMEMBER !"
   echo ""
   echo "YOU NEED TO RUN 'Configure' (0) First !"
   echo "==================================================="
   echo
   echo
   exit 0
fi
echo $PWD/scripts/CreaTools-configure.sh
echo --- beg
more $PWD/scripts/CreaTools-configure.sh
echo --- end
source $PWD/scripts/CreaTools-configure.sh

   echo "------"
   echo $PWD/scripts/CreaTools-configure.sh
   echo --generationdir--
   echo $generationdir
   echo --docgeneration--
   echo $docgeneration
   echo --installPrefix--
   echo $installPrefix
   echo --installPrefixThird--
   echo $installPrefixThird
   echo --buildType--
   echo $buildType
   echo --gdcmVersion--
   echo $gdcmVersion
   echo --ITKVersion--
   echo $ITKVersion
#   echo --sourcesFrom--
#   echo $sourcesFrom
#   echo --scriptDir--
#   echo $scriptDir
#   echo --start_point--
#   echo $start_point
   echo "------"


#EED 2017-03-24
  source $PWD/scripts/LocalFunctions.sh
  if [ `getDistrib` == "CentOS" ] && [ `getKernelVersion` < "2.6.34" ]
  then
	stdCompiler=c++98
  else
	stdCompiler=c++03
  fi



scriptDir=$PWD
sourcesDir=$generationdir/thirdparty_sources
binDir=$generationdir/thirdparty_bin
#EED itkfile=InsightToolkit-3.20.0.patchCreatis.tar.gz

if [ ! -e $generationdir ]
then
   mkdir -p $generationdir
   chown -R $loginUserName  $generationdir
   chgrp -R $loginGroupName $generationdir

fi
if [ ! -e $sourcesDir ]
then
   mkdir -p $sourcesDir
   #was : (pb on MacOS?)
   #chown -R $loginUserName:$loginGroupName $sourcesDir
   chown -R $loginUserName  $sourcesDir
   chgrp -R $loginGroupName $sourcesDir
fi

if [ ! -e $binDir ]
then
   mkdir -p $binDir
   chown -R $loginUserName  $binDir
   chgrp -R $loginGroupName $binDir
fi

  echo "we remove old stuff"
  if [ $ITKVersion = ITK3 ]
  then
     rm -rf $sourcesDir/InsightToolkit*
     rm -rf $binDir/InsightToolkit*
  else
     rm -rf $sourcesDir/ITK*
     rm -rf $binDir/ITKt*
  fi
  cd $sourcesDir

 echo "we download new stuff"
  if [ $ITKVersion = ITK3 ]
  then
     # deal with ITK3
     #EED itkfile=InsightToolkit-3.20.0.patchCreatis.tar.gz
     #EED libname=InsightToolkit-3.20.0

     #EED itkfile=InsightToolkit-3.20.1.tar.gz
     #EED libname=InsightToolkit-3.20.1

     itkfile=InsightToolkit-3.20.1-patchCreatis.tgz
     libname=InsightToolkit-3.20.1-patchCreatis

  else
    # deal with ITK4
    itkfile=ITK4.0.tgz
    libname=ITK
  fi

  if [ $OperatingSystem = "MacOS" ]
    then
      curl -O http://www.creatis.insa-lyon.fr/~davila/creatools_back_site/crea_ThirdParty_Libraries/source/$itkfile
  else
##EED19mai2015      wget http://www.creatis.insa-lyon.fr/software/public/creatools/crea_ThirdParty_Libraries/source/$itkfile
      wget http://www.creatis.insa-lyon.fr/~davila/creatools_back_site/crea_ThirdParty_Libraries/source/$itkfile
  fi
  tar -xzvf $itkfile


#fi # JPR ------------1

#if [ $buildType = "Debug" ]
#then
#   debug="ON"
#else
#   debug="OFF"
#fi

# the following stupid test is used at debug time; Please don't remove!
#if [ true = false ]
if [ true = true ]
then

  dirInstall=$binDir/$libname-Bin
  export ITK_DIR=$installPrefixThird/lib/InsightToolkit/
  mkdir -p $dirInstall
  cd $dirInstall

  cmake -G"Unix Makefiles" -H$sourcesDir/$libname -B$dirInstall/
  ##cmake -G"CodeBlocks - Unix Makefiles" -H$sourcesDir/$libname -B$dirInstall/
  cmake -D CMAKE_BUILD_TYPE:STRING=$buildType -D CMAKE_INSTALL_PREFIX:PATH=$installPrefixThird CMakeCache.txt
  cmake -D BUILD_EXAMPLES:BOOL=OFF -D BUILD_TESTING:BOOL=OFF -D BUILD_SHARED_LIBS:BOOL=ON -D ITK_USE_REVIEW:BOOL=ON CMakeCache.txt
  if [ $ITKVersion = ITK4 ]
  then
     cmake -D ITKV3_COMPATIBILITY:BOOL=ON -D ITKGroup_Nonunit:BOOL=ON -D  ITKGroup_IO:BOOL=ON  -D Module_ITK-Deprecated:BOOL=ON -D Module_ITK-Review:BOOL=ON  CMakeCache.txt        
  fi
  cmake -D CMAKE_CXX_FLAGS:STRING=-std=${stdCompiler} CMakeCache.txt

  #uncomment following line if you want to use the bleeding edge of GDCM2!
  #cmake -D ITK_USE_SYSTEM_GDCM:BOOL=ON CMakeCache.txt
  cmake CMakeCache.txt
  make -j $corenumber
  make -j $corenumber install
  cd ..
fi
